#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""

"""
from SLiCAP import *

fileName = "bandwidthBudgeting"
specFileName = "specifications.csv"

# Define an instruction
i1 = instruction()
i1.setCircuit(fileName + '.cir')

# import the specifications
specs = csv2specs(specFileName)

# Define the circuit parameters from the specifications
specs2circuit(specs, i1)

htmlPage("Circuit Data")
head2html("Circuit diagram")
img2html(fileName + ".svg", 1000)
netlist2html(fileName + ".cir")
elementData2html(i1.circuit)
params2html(i1.circuit)
htmlPage('Calculation of damping resistances')

head2html("Tranmitter damping resistance")
text2html("We will apply critical damping ($Q=\\frac{1}{2}\\sqrt{2}$),")
text2html("The value $R_{ds}$ of the damping resistor in parallel with the " +
          "transmit coil should then be")
Rds = sp.sqrt(0.5*i1.getParValue("L_s")/i1.getParValue("C_s"))
eqn2html("R_ds", Rds, units="Omega")
i1.defPar("R_ds", Rds)

head2html("Receiver damping resistance")
text2html("We will apply critical damping ($Q=\\frac{1}{2}\\sqrt{2}$),")
text2html("The value $R_{dr}$ of the damping resistor in parallel with the " +
          "receive coil should then be")
Rdr = sp.sqrt(0.5*i1.getParValue("L_r")/i1.getParValue("C_r"))

eqn2html("R_dr", Rdr, units="Omega")
i1.defPar("R_dr", Rdr)

i1.setSimType('numeric')
i1.setGainType('gain')
i1.setDataType('laplace')
i1.setSource('V1')
i1.setDetector('V_out')

laplaceResult = i1.execute()
text2html("The figure below shows the transfer with an instantaneous " +
          "transadmittance transmitter amplifier and an integrating voltage " +
          "receiver amplifier, and damped antenna resonance.")

magFig = plotSweep("magFigDamped", "Magnitude of hearing loop Transfer with damping", laplaceResult, 10, 1E6, 500, show=True)

fig2html(magFig, 600)

# Update and save the design data

specs.append(
    specItem(
        "R_ds",
        description = "Transmitter damping resistance",
        value    = Rds,
        units       = "Omega",
        specType    = "design",
    )
)

specs.append(
    specItem(
        "R_dr",
        description = "Receiver damping resistance",
        value    = Rdr,
        units       = "Omega",
        specType    = "design",
    )
)

# Save the specifications
specs2csv(specs, "specifications.csv")

# Display the specifications on a html page.
htmlPage("Updated specifications")
specs2html(specs)